@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use autodie;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 # CPAN::Reporter spits out random output we don't want, and we don't want to
 # report these tests anyway.
@@ -149,6 +149,10 @@ sub test_module {
     $name =~ s/-/::/g;
 
     my $dist = _get_distro($name);
+    unless ($dist) {
+        $Test->diag(qq{Could't find a distro for $name});
+        return;
+    }
 
     $Test->diag( 'Testing ' . $dist->base_id );
 
@@ -414,7 +418,7 @@ sub _run_tests_for_dir {
 
     local $CWD = $dir;
 
-    if ( -f 'Build.PL' ) {
+    if ( -e 'Build.PL' ) {
         return
             unless _run_commands(
             ['./Build'],
@@ -461,10 +465,10 @@ sub _run_tests {
     };
 
     my $cmd;
-    if ( -f 'Build' ) {
+    if ( -e 'Build' ) {
         $cmd = [qw( ./Build test )];
     }
-    elsif ( -f 'Makefile' ) {
+    elsif ( -e 'Makefile' ) {
         $cmd = [qw( make test )];
     }
     else {
@@ -545,7 +549,7 @@ Test::DependentModules - Test all modules which depend on your module
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
